.. _main_module:

:mod:`socketio`
===============

This module holds the main hooking function for your framework of choice.

Call the `socketio_manage` function from a view in your framework and this
will be the beginning of your Socket.IO journey.

.. automodule:: socketio
    :members:
    :undoc-members:
    :show-inheritance:
